package com.ruoyi.rocketmq.service;

import java.util.List;
import com.ruoyi.rocketmq.domain.RmPolicyDeviceDetails;

/**
 * 客户端策略关联Service接口
 * 
 * @author gyt
 * @date 2025-10-22
 */
public interface IRmPolicyDeviceDetailsService 
{
    /**
     * 查询客户端策略关联
     * 
     * @param id 客户端策略关联主键
     * @return 客户端策略关联
     */
    public RmPolicyDeviceDetails selectRmPolicyDeviceDetailsById(Long id);

    /**
     * 查询客户端策略关联列表
     * 
     * @param rmPolicyDeviceDetails 客户端策略关联
     * @return 客户端策略关联集合
     */
    public List<RmPolicyDeviceDetails> selectRmPolicyDeviceDetailsList(RmPolicyDeviceDetails rmPolicyDeviceDetails);

    /**
     * 新增客户端策略关联
     * 
     * @param rmPolicyDeviceDetails 客户端策略关联
     * @return 结果
     */
    public int insertRmPolicyDeviceDetails(RmPolicyDeviceDetails rmPolicyDeviceDetails);

    /**
     * 修改客户端策略关联
     * 
     * @param rmPolicyDeviceDetails 客户端策略关联
     * @return 结果
     */
    public int updateRmPolicyDeviceDetails(RmPolicyDeviceDetails rmPolicyDeviceDetails);

    /**
     * 批量删除客户端策略关联
     * 
     * @param ids 需要删除的客户端策略关联主键集合
     * @return 结果
     */
    public int deleteRmPolicyDeviceDetailsByIds(Long[] ids);

    /**
     * 删除客户端策略关联信息
     * 
     * @param id 客户端策略关联主键
     * @return 结果
     */
    public int deleteRmPolicyDeviceDetailsById(Long id);
}
