package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.RmPolicyDeviceDetails;
import com.ruoyi.rocketmq.service.IRmPolicyDeviceDetailsService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 客户端策略关联Controller
 * 
 * @author gyt
 * @date 2025-10-22
 */
@RestController
@RequestMapping("/policyDeviceDetails")
public class RmPolicyDeviceDetailsController extends BaseController
{
    @Autowired
    private IRmPolicyDeviceDetailsService rmPolicyDeviceDetailsService;

    /**
     * 查询客户端策略关联列表
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:list")
    @GetMapping("/list")
    public TableDataInfo list(RmPolicyDeviceDetails rmPolicyDeviceDetails)
    {
        startPage();
        List<RmPolicyDeviceDetails> list = rmPolicyDeviceDetailsService.selectRmPolicyDeviceDetailsList(rmPolicyDeviceDetails);
        return getDataTable(list);
    }

    /**
     * 导出客户端策略关联列表
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:export")
    @Log(title = "客户端策略关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmPolicyDeviceDetails rmPolicyDeviceDetails)
    {
        List<RmPolicyDeviceDetails> list = rmPolicyDeviceDetailsService.selectRmPolicyDeviceDetailsList(rmPolicyDeviceDetails);
        ExcelUtil<RmPolicyDeviceDetails> util = new ExcelUtil<RmPolicyDeviceDetails>(RmPolicyDeviceDetails.class);
        util.exportExcel(response, list, "客户端策略关联数据");
    }

    /**
     * 获取客户端策略关联详细信息
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmPolicyDeviceDetailsService.selectRmPolicyDeviceDetailsById(id));
    }

    /**
     * 新增客户端策略关联
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:add")
    @Log(title = "客户端策略关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmPolicyDeviceDetails rmPolicyDeviceDetails)
    {
        return toAjax(rmPolicyDeviceDetailsService.insertRmPolicyDeviceDetails(rmPolicyDeviceDetails));
    }

    /**
     * 修改客户端策略关联
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:edit")
    @Log(title = "客户端策略关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmPolicyDeviceDetails rmPolicyDeviceDetails)
    {
        return toAjax(rmPolicyDeviceDetailsService.updateRmPolicyDeviceDetails(rmPolicyDeviceDetails));
    }

    /**
     * 删除客户端策略关联
     */
    @RequiresPermissions("rocketmq:policyDeviceDetails:remove")
    @Log(title = "客户端策略关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmPolicyDeviceDetailsService.deleteRmPolicyDeviceDetailsByIds(ids));
    }
}
